LogModel class
Constructors
Properties
- argument → String?
-
final
- body → String?
-
final
- columnNumber → int?
-
final
- deviceId → String?
-
final
- deviceType → String?
-
final
- endpoint → String?
-
final
- error → String?
-
final
- errorFrom → String?
-
final
- exception → String?
-
final
- filePath → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineNumber → int?
-
final
- method → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → String?
-
final
- time → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited